DeviceDescriptor

Struct DeviceDescriptor 

pub struct DeviceDescriptor {
    pub mouse: Option<MouseDescriptor>,
    pub sensor: Option<SensorDescriptor>,
    pub touch: Option<TouchDescriptor>,
    pub keyboard: Option<KeyboardDescriptor>,
    pub consumer_control: Option<ConsumerControlDescriptor>,
    pub device_information: Option<DeviceInformation>,
    /* private fields */
}
DeviceDescriptor describes a physical input device. Some physical devices may send multiple types of reports (E.g: a physical touchscreen can send touch and stylus reports, so it will have both a TouchDescriptor and a StylusDescriptor).

Fields

mouse: Option<MouseDescriptor>

Describes the mouse part of the device.

Optional. Present iff the device is/has a mouse.

sensor: Option<SensorDescriptor>

Describes the sensor part of the device.

Optional. Present iff the device is/has a sensor.

touch: Option<TouchDescriptor>

Describes the touch part (such as a touchscreen or touchpad) of the device.

Optional. Present iff the device is/has a touch device.

keyboard: Option<KeyboardDescriptor>

Describes the keyboard part of the device.

Optional. Present iff the device is/has a keyboard.

consumer_control: Option<ConsumerControlDescriptor>

Describes the consumer control part of the device.

Optional. Present iff the device is/has a consumer control device.

device_information: Option<DeviceInformation>

Identifies the physical device.

Required.