DeviceInformation

Struct DeviceInformation 

pub struct DeviceInformation {
    pub vendor_id: Option<u32>,
    pub product_id: Option<u32>,
    pub version: Option<u32>,
    pub polling_rate: Option<i64>,
    pub manufacturer_name: Option<String>,
    pub product_name: Option<String>,
    pub serial_number: Option<String>,
    /* private fields */
}
DeviceInformation provides more information about the device and lets a client distinguish between devices (e.g between two touchscreens that come from different vendors). If the device is a HID device, then the id information will come from the device itself. Other, non-HID devices may assign the ids in the driver, so it will be the driver author’s responsibility to assign sensible ids.

Fields

vendor_id: Option<u32>

Required.

product_id: Option<u32>

Required.

version: Option<u32>

Optional.

polling_rate: Option<i64>

The time interval between each poll of the device.

Optional.

manufacturer_name: Option<String>

Human-readable name of the manufacturer. Optional. Must be non-empty if present.

product_name: Option<String>

Human-readable name of the product. Optional. Must be non-empty if present.

serial_number: Option<String>

Serial number of the device. Optional. Must be non-empty if present.