FeatureReport

Struct FeatureReport 

pub struct FeatureReport {
    pub sensor: Option<SensorFeatureReport>,
    pub touch: Option<TouchFeatureReport>,
    /* private fields */
}
A single report containing the feature information for an input device. Feature reports obtained from the device show the current state of the device. Sending a feature report to the device sets the device in that state.

Fields

sensor: Option<SensorFeatureReport>

Optional. Present iff the device is/has a sensor.

touch: Option<TouchFeatureReport>

Optional. Present iff the device is/has a touch device.