pub struct InputDeviceGetInputReportsReaderV2Request {
pub reader: ServerEnd<InputReportsReaderV2Marker>,
pub max_unacknowledged_reports_limit: u16,
}Fields
reader: ServerEnd<InputReportsReaderV2Marker>max_unacknowledged_reports_limit: u16The maximum number of unacknowledged OnInputReports events that the client
requests the device to allow in flight simultaneously.
The client should determine this value based on product configuration and
processing capabilities. The device uses this limit as an upper bound when
deciding the effective max_unacknowledged_reports returned in the response.