InputReport

Struct InputReport 

pub struct InputReport {
    pub event_time: Option<i64>,
    pub mouse: Option<MouseInputReport>,
    pub trace_id: Option<u64>,
    pub sensor: Option<SensorInputReport>,
    pub touch: Option<TouchInputReport>,
    pub keyboard: Option<KeyboardInputReport>,
    pub consumer_control: Option<ConsumerControlInputReport>,
    pub report_id: Option<u8>,
    pub wake_lease: Option<EventPair>,
    /* private fields */
}
An InputReport is a single report that is created by an input device. An InputReport can contain one of many different report types. The report types are not mutually exclusive. The event_time is the time in nanoseconds when the report was generated.

Fields

event_time: Option<i64>

The monotonic time when the event was generated.

Required.

mouse: Option<MouseInputReport>

Optional. Present iff the device reports mouse input.

trace_id: Option<u64>

Unique ID to connect trace async begin/end events.

Optional.

sensor: Option<SensorInputReport>

Optional. Present iff the device reports sensor input.

touch: Option<TouchInputReport>

Optional. Present iff the device reports touch input.

keyboard: Option<KeyboardInputReport>

Optional. Present iff the device reports keyboard input.

consumer_control: Option<ConsumerControlInputReport>

Optional. Present iff the device reports consumer control input.

report_id: Option<u8>

A device may have multiple input descriptors of the same type. This field specifies which descriptor this InputReport corresponds to. Omitted if the device has no more than one descriptor for each type.

Optional.

wake_lease: Option<EventPair>

Optional wake lease for power baton passing.