pub struct InputReportsReaderV2Marker;Trait Implementations
Sourceimpl Clone for InputReportsReaderV2Marker
impl Clone for InputReportsReaderV2Marker
Sourcefn clone(&self) -> InputReportsReaderV2Marker
fn clone(&self) -> InputReportsReaderV2Marker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for InputReportsReaderV2Marker
Sourceimpl Debug for InputReportsReaderV2Marker
impl Debug for InputReportsReaderV2Marker
impl Eq for InputReportsReaderV2Marker
Sourceimpl Hash for InputReportsReaderV2Marker
impl Hash for InputReportsReaderV2Marker
Sourceimpl Ord for InputReportsReaderV2Marker
impl Ord for InputReportsReaderV2Marker
Sourcefn cmp(&self, other: &InputReportsReaderV2Marker) -> Ordering
fn cmp(&self, other: &InputReportsReaderV2Marker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for InputReportsReaderV2Marker
impl PartialEq for InputReportsReaderV2Marker
Sourcefn eq(&self, other: &InputReportsReaderV2Marker) -> bool
fn eq(&self, other: &InputReportsReaderV2Marker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for InputReportsReaderV2Marker
impl PartialOrd for InputReportsReaderV2Marker
Sourceimpl ProtocolMarker for InputReportsReaderV2Marker
impl ProtocolMarker for InputReportsReaderV2Marker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) InputReportsReaderV2"
const DEBUG_NAME: &'static str = "(anonymous) InputReportsReaderV2"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = InputReportsReaderV2Proxy
type Proxy = InputReportsReaderV2Proxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = InputReportsReaderV2RequestStream
type RequestStream = InputReportsReaderV2RequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = InputReportsReaderV2SynchronousProxy
type SynchronousProxy = InputReportsReaderV2SynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl StructuralPartialEq for InputReportsReaderV2Marker