pub struct InputReportsReaderV2OnInputReportsRequest {
pub reports: Vec<InputReport>,
pub last_report_stamp: u64,
}Fields
reports: Vec<InputReport>last_report_stamp: u64Each report is associated with a strictly monotonic numerical report
stamp. This field contains the report stamp for the last element in
reports.